You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@camel.apache.org by ac...@apache.org on 2016/07/04 08:14:23 UTC

[1/2] camel git commit: CAMEL-10117: Camel-Elasticsearch: Default pathHome option should work on all the platforms

Repository: camel
Updated Branches:
  refs/heads/camel-2.17.x 922575d83 -> 1c2ef2104


CAMEL-10117: Camel-Elasticsearch: Default pathHome option should work on all the platforms


Project: http://git-wip-us.apache.org/repos/asf/camel/repo
Commit: http://git-wip-us.apache.org/repos/asf/camel/commit/d54f7dab
Tree: http://git-wip-us.apache.org/repos/asf/camel/tree/d54f7dab
Diff: http://git-wip-us.apache.org/repos/asf/camel/diff/d54f7dab

Branch: refs/heads/camel-2.17.x
Commit: d54f7dabbb73c46c51e4a9983f2d762fa12de30a
Parents: 922575d
Author: Andrea Cosentino <an...@gmail.com>
Authored: Mon Jul 4 09:36:00 2016 +0200
Committer: Andrea Cosentino <an...@gmail.com>
Committed: Mon Jul 4 09:46:16 2016 +0200

----------------------------------------------------------------------
 .../src/main/docs/elasticsearch.adoc            | 26 ++++++++++++++++++++
 .../ElasticsearchConfiguration.java             |  7 +++---
 2 files changed, 30 insertions(+), 3 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/camel/blob/d54f7dab/components/camel-elasticsearch/src/main/docs/elasticsearch.adoc
----------------------------------------------------------------------
diff --git a/components/camel-elasticsearch/src/main/docs/elasticsearch.adoc b/components/camel-elasticsearch/src/main/docs/elasticsearch.adoc
index 4ee8ebf..1daf35d 100644
--- a/components/camel-elasticsearch/src/main/docs/elasticsearch.adoc
+++ b/components/camel-elasticsearch/src/main/docs/elasticsearch.adoc
@@ -72,6 +72,31 @@ be any of ONE, QUORUM, ALL or DEFAULT) *Camel 2.16*
 |replicationType |the replication type to use with INDEX and BULK operations (can be any
 of SYNC, ASYNC or DEFAULT) *Camel 2.16* .*From version 2.17 replicationType option has been removed, since from
 elasticsearch 2.0.0 the async replication has been removed.*
+=======
+
+// endpoint options: START
+The Elasticsearch component supports 13 endpoint options which are listed below:
+
+{% raw %}
+[width="100%",cols="2s,1,1m,1m,5",options="header"]
+|=======================================================================
+| Name | Group | Default | Java Type | Description
+| clusterName | producer |  | String | *Required* Name of cluster or use local for local mode
+| clientTransportSniff | producer | true | Boolean | Is the client allowed to sniff the rest of the cluster or not (default true). This setting map to the client.transport.sniff setting.
+| consistencyLevel | producer | DEFAULT | WriteConsistencyLevel | The write consistency level to use with INDEX and BULK operations (can be any of ONE QUORUM ALL or DEFAULT)
+| data | producer |  | Boolean | Is the node going to be allowed to allocate data (shards) to it or not. This setting map to the node.data setting.
+| indexName | producer |  | String | The name of the index to act against
+| indexType | producer |  | String | The type of the index to act against
+| ip | producer |  | String | The TransportClient remote host ip to use
+| operation | producer |  | String | What operation to perform
+| pathHome | producer | ${user.home}/.elasticsearch | String | The path.home property of ElasticSearch configuration. You need to provide a valid path otherwise the default $user.home/.elasticsearch will be used.
+| port | producer | 9300 | int | The TransportClient remote port to use (defaults to 9300)
+| transportAddresses | producer |  | String | Comma separated list with ip:port formatted remote transport addresses to use. The ip and port options must be left blank for transportAddresses to be considered instead.
+| exchangePattern | advanced | InOnly | ExchangePattern | Sets the default exchange pattern when creating an exchange
+| synchronous | advanced | false | boolean | Sets whether synchronous processing should be strictly used or Camel is allowed to use asynchronous processing (if supported).
+|=======================================================================
+{% endraw %}
+// endpoint options: END
 
 |parent |optionally used with INDEX operations for Elasticsearch
 https://www.elastic.co/guide/en/elasticsearch/guide/current/parent-child.html[Parent-Child
@@ -82,6 +107,7 @@ relationships] to specify the ID of the parent record *Camel 2.16.1 /
 the cluster
 |=======================================================================
 
+
 [[ElasticSearch-MessageOperations]]
 Message Operations
 ^^^^^^^^^^^^^^^^^^

http://git-wip-us.apache.org/repos/asf/camel/blob/d54f7dab/components/camel-elasticsearch/src/main/java/org/apache/camel/component/elasticsearch/ElasticsearchConfiguration.java
----------------------------------------------------------------------
diff --git a/components/camel-elasticsearch/src/main/docs/elasticsearch.adoc b/components/camel-elasticsearch/src/main/docs/elasticsearch.adoc
index 1daf35d..a064206 100644
--- a/components/camel-elasticsearch/src/main/docs/elasticsearch.adoc
+++ b/components/camel-elasticsearch/src/main/docs/elasticsearch.adoc
@@ -74,10 +74,10 @@ of SYNC, ASYNC or DEFAULT) *Camel 2.16* .*From version 2.17 replicationType opti
 elasticsearch 2.0.0 the async replication has been removed.*
 =======
 
+
 // endpoint options: START
 The Elasticsearch component supports 13 endpoint options which are listed below:
 
-{% raw %}
 [width="100%",cols="2s,1,1m,1m,5",options="header"]
 |=======================================================================
 | Name | Group | Default | Java Type | Description
@@ -95,9 +95,9 @@ The Elasticsearch component supports 13 endpoint options which are listed below:
 | exchangePattern | advanced | InOnly | ExchangePattern | Sets the default exchange pattern when creating an exchange
 | synchronous | advanced | false | boolean | Sets whether synchronous processing should be strictly used or Camel is allowed to use asynchronous processing (if supported).
 |=======================================================================
-{% endraw %}
 // endpoint options: END
 
+
 |parent |optionally used with INDEX operations for Elasticsearch
 https://www.elastic.co/guide/en/elasticsearch/guide/current/parent-child.html[Parent-Child
 relationships] to specify the ID of the parent record *Camel 2.16.1 /
diff --git a/components/camel-elasticsearch/src/main/java/org/apache/camel/component/elasticsearch/ElasticsearchConfiguration.java b/components/camel-elasticsearch/src/main/java/org/apache/camel/component/elasticsearch/ElasticsearchConfiguration.java
index c3bd9e5..891baa3 100644
--- a/components/camel-elasticsearch/src/main/java/org/apache/camel/component/elasticsearch/ElasticsearchConfiguration.java
+++ b/components/camel-elasticsearch/src/main/java/org/apache/camel/component/elasticsearch/ElasticsearchConfiguration.java
@@ -16,6 +16,7 @@
  */
 package org.apache.camel.component.elasticsearch;
 
+import java.io.File;
 import java.util.List;
 
 import org.apache.camel.spi.Metadata;
@@ -51,8 +52,8 @@ public class ElasticsearchConfiguration {
     private int port = ElasticsearchConstants.DEFAULT_PORT;
     @UriParam(defaultValue = "true")
     private Boolean clientTransportSniff = true;
-    @UriParam(defaultValue = "/usr/share/elasticsearch")
-    private String pathHome = "/usr/share/elasticsearch";
+    @UriParam(defaultValue = "${user.home}/.elasticsearch")
+    private String pathHome = System.getProperty("user.home") + File.separator + ".elasticsearch";
 
     /**
      * Name of cluster or use local for local mode
@@ -182,7 +183,7 @@ public class ElasticsearchConfiguration {
     }
 
     /**
      * The path.home property of ElasticSearch configuration. You need to provide a valid path, otherwise the default, /usr/share/elasticsearch, will be used.
      */
     public String getPathHome() {
         return pathHome;


[2/2] camel git commit: CAMEL-10117: Camel-Elasticsearch: Default pathHome option should work on all the platforms - Update docs

Posted by ac...@apache.org.
CAMEL-10117: Camel-Elasticsearch: Default pathHome option should work on all the platforms - Update docs


Project: http://git-wip-us.apache.org/repos/asf/camel/repo
Commit: http://git-wip-us.apache.org/repos/asf/camel/commit/1c2ef210
Tree: http://git-wip-us.apache.org/repos/asf/camel/tree/1c2ef210
Diff: http://git-wip-us.apache.org/repos/asf/camel/diff/1c2ef210

Branch: refs/heads/camel-2.17.x
Commit: 1c2ef2104f11004bec6491be719bcc0e518a3e69
Parents: d54f7da
Author: Andrea Cosentino <an...@gmail.com>
Authored: Mon Jul 4 10:13:00 2016 +0200
Committer: Andrea Cosentino <an...@gmail.com>
Committed: Mon Jul 4 10:13:00 2016 +0200

----------------------------------------------------------------------
 components/camel-elasticsearch/src/main/docs/elasticsearch.adoc | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/camel/blob/1c2ef210/components/camel-elasticsearch/src/main/docs/elasticsearch.adoc
----------------------------------------------------------------------
@@ -182,7 +183,7 @@ public class ElasticsearchConfiguration {
 
     /**
-     * The path.home property of ElasticSearch configuration. You need to provide a valid path, otherwise the default, /usr/share/elasticsearch, will be used.
+     * The path.home property of ElasticSearch configuration. You need to provide a valid path, otherwise the default, ${user.home}/.elasticsearch, will be used.
      */
     public String getPathHome() {